.. currentmodule:: dalia

#############
API reference
#############

This page provides an auto-generated summary of dalia's API.

.. autosummary::
   :toctree: generated/

   read_csvv

   csvv.Csvv
